@@ -142,7 +142,17 @@ die "Conflicting sheetname opt and !suffix not caught" if $@ eq "";
 
 # "Read" a csv; should be a pass-thru without conversion
 {
-  read_spreadsheet {verbose => $verbose}, $local_testcsv;
+### This is failing to auto-detect $local_testcsv as a CSV on Solaris ;
+### try to show enough information to debug it...
+eval {
+  read_spreadsheet {debug => $debug, verbose => $verbose}, $local_testcsv;
+};
+if ($@) {
+  warn __FILE__,":",__LINE__," - failed: $@\nRE_TRYING WITH DEBUG...\n";
+  read_spreadsheet {debug => 1, verbose => 1}, $local_testcsv;
+  die "should have died by now";
+}
+
   verif_Sheet1 "(extracted csv)";
   my $hash = doconvert(inpath=>$local_testcsv, cvt_to => 'csv');
   die "expected null converstion" unless $hash->{outpath} eq $local_testcsv;
